@@ -1,4 +1,4 @@
-from dataservice.clients import HttpXClient
+from dataservice.clients import HttpXClient, PlaywrightClient, PlaywrightPage
 from dataservice.config import (
     CacheConfig,
     RateLimiterConfig,
@@ -9,21 +9,24 @@ from dataservice.data import BaseDataItem, DataWrapper
 from dataservice.exceptions import DataServiceException, RetryableException
 from dataservice.logs import setup_logging
 from dataservice.models import FailedRequest, Request, Response
-from dataservice.service import DataService
+from dataservice.service import AsyncDataService, DataService
 
 __all__ = [
+    "AsyncDataService",
     "BaseDataItem",
+    "CacheConfig",
     "DataService",
+    "DataServiceException",
     "DataWrapper",
+    "FailedRequest",
     "HttpXClient",
+    "PlaywrightClient",
+    "PlaywrightPage",
+    "RateLimiterConfig",
     "Request",
     "Response",
-    "FailedRequest",
-    "DataServiceException",
     "RetryableException",
-    "ServiceConfig",
-    "CacheConfig",
-    "RateLimiterConfig",
     "RetryConfig",
+    "ServiceConfig",
     "setup_logging",
 ]
